# Keetbot
**Keetbot** is a very simple python library for making your [keet messenger](https://keet.io/) bots 
### Installing
With pip
```pip install keet```

From source
```pip install git+https://github.com/lmemq/keetbot.git```

Upgrade
```pip install keet --upgrade```
### First bot
```python
import keet
...soon...
```
###### Warning: this is very simple lib, it may have a lot of bugs
> THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
###### If you like keetbot, please star repository
